library jwt_io;

import 'dart:convert';

class JwtToken {
  static Map<String, dynamic> header(String token) {
    final payloadBase64 = token.split(".")[0];
    final normalizedPayload = base64.normalize(payloadBase64);
    final payloadString = utf8.decode(base64.decode(normalizedPayload));
    return json.decode(payloadString) as Map<String, dynamic>;
  }

  static Map<String, dynamic> payload(String token) {
    final payloadBase64 = token.split(".")[1];
    final normalizedPayload = base64.normalize(payloadBase64);
    final payloadString = utf8.decode(base64.decode(normalizedPayload));
    return json.decode(payloadString) as Map<String, dynamic>;
  }

  static bool isExpired(String token) {
    try {
      final expirationDate = getExpirationDate(token);
      return DateTime.now().isAfter(expirationDate);
    } catch (error) {
      return true;
    }
  }

  static DateTime getExpirationDate(String token) {
    final decodedToken = payload(token);
    final expirationDate = DateTime.fromMillisecondsSinceEpoch(0)
        .add(Duration(seconds: decodedToken['exp'] as int));
    return expirationDate;
  }

  static Duration getTokenTime(String token) {
    final decodedToken = payload(token);
    final expirationDate = DateTime.fromMillisecondsSinceEpoch(0)
        .add(Duration(seconds: decodedToken["iat"] as int));
    return DateTime.now().difference(expirationDate);
  }
}
